# Search Tools
This is a library containing some tools for search science. Many of these tools are available through other libraries, so the primary contribution of this library is to implement them in a distributed fashion via pyspark. This library is intended primarily for use with pyspark.

This library is not intended for public use, just for my friends, so please don't bug me about your issues.


## Installation `pip install search-tools` .
